@@ -72,6 +72,8 @@ var (
 
 	mlxVendorID   = "15b3"
 	intelVendorID = "8086"
+
+	sriovNicsTable []TableEntry
 )
 
 func init() {
@@ -87,6 +89,21 @@ func init() {
 		enforcedPerformanceProfileName = performanceProfileName
 	}
 
+	// When running in dry run as part of the docgen we want to skip the creation of descriptions for the nics table entries.
+	// This way we don't add tests descriptions for the dynamically created table entries that depend on the environment they run on.
+	isFillRun := os.Getenv("FILL_RUN") != ""
+	if !isFillRun {
+		supportedNicsConfigMap, err := getSupportedSriovNics()
+		if err != nil {
+			sriovNicsTable = append(sriovNicsTable, Entry("Failed getting supported SR-IOV nics", err.Error()))
+		}
+
+		for k, v := range supportedNicsConfigMap {
+			ids := strings.Split(v, " ")
+			sriovNicsTable = append(sriovNicsTable, Entry(k, ids[0], ids[1]))
+		}
+	}
+
 	// Reuse the sriov client
 	// Use the SRIOV test client
 	sriovclient = sriovtestclient.New("")
@@ -321,7 +338,13 @@ var _ = Describe("dpdk", func() {
 			})
 
 			It("should allow to remove the hugepage file inside the pod", func() {
-				buff, err := pods.ExecCommand(client.Client, *dpdkWorkloadPod, []string{"rm", "/mnt/huge/rtemap_0"})
+				By("Checking hugepage file exist in the directory")
+				buff, err := pods.ExecCommand(client.Client, *dpdkWorkloadPod, []string{"ls", "/mnt/huge/"})
+				Expect(err).ToNot(HaveOccurred(), fmt.Sprintf("failed to execute the list command error: %s", buff.String()))
+				Expect(strings.Contains(buff.String(), "rtemap")).To(BeTrue())
+
+				hugePagesFile := strings.TrimSuffix(buff.String(), "\r\n")
+				buff, err = pods.ExecCommand(client.Client, *dpdkWorkloadPod, []string{"rm", fmt.Sprintf("/mnt/huge/%s", hugePagesFile)})
 				Expect(err).ToNot(HaveOccurred(), fmt.Sprintf("failed to execute the remove command error: %s", buff.String()))
 			})
 		})
@@ -383,6 +406,8 @@ var _ = Describe("dpdk", func() {
 		var out string
 
 		execute.BeforeAll(func() {
+			Expect(len(sriovNicsTable)).To(BeNumerically(">", 1), sriovNicsTable[0].Parameters[0])
+
 			sriovInfos, err = sriovcluster.DiscoverSriov(sriovclient, namespaces.SRIOVOperator)
 			Expect(err).ToNot(HaveOccurred())
 
@@ -448,10 +473,7 @@ var _ = Describe("dpdk", func() {
 			checkTxOnly(out)
 
 		},
-			Entry("Intel Corporation Ethernet Controller XXV710 for 25GbE SFP28", intelVendorID, "158b"),
-			Entry("Ethernet Controller XXV710 Intel(R) FPGA Programmable Acceleration Card N3000 for Networking", intelVendorID, "0d58"),
-			Entry("Ethernet controller: Mellanox Technologies MT27710 Family [ConnectX-4 Lx]", mlxVendorID, "1015"),
-			Entry("Ethernet controller: Mellanox Technologies MT27800 Family [ConnectX-5]", mlxVendorID, "1017"))
+			sriovNicsTable...)
 	})
 
 	Context("Downward API", func() {
@@ -1351,6 +1373,17 @@ func RestorePerformanceProfile() {
 	Expect(err).ToNot(HaveOccurred())
 }
 
+func getSupportedSriovNics() (map[string]string, error) {
+	supportedNicsConfigMap := &corev1.ConfigMap{}
+
+	err := client.Client.Get(context.TODO(), goclient.ObjectKey{Name: utils.SriovSupportedNicsCM, Namespace: namespaces.SRIOVOperator}, supportedNicsConfigMap)
+	if err != nil {
+		return nil, err
+	}
+
+	return supportedNicsConfigMap.Data, nil
+}
+
 func CleanSriov() {
 	// This clean only the policy and networks with the prefix of test
 	err := sriovnamespaces.CleanPods(namespaces.DpdkTest, sriovclient)
